@@ -29,7 +29,6 @@ using System.Xml;
 
 using NDesk.DBus;
 using org.freedesktop.DBus;
-//using org.freedesktop.Telepathy;
 using Tapioca;
 
 using Gtk;
@@ -49,27 +48,15 @@ namespace Banter
 		#region Private Types
 		private bool initialized = false;
 		private ActionManager actionManager;
+		private PersonSync personSync;
 		//private NotificationArea tray;
 		private Gdk.Pixbuf appPixBuf;
 		private Gnome.Program program = null;
 		private Dictionary <uint, Person> persons;
 		private Dictionary <string, ChatWindow> chatWindows;
-		//private Person me;
 		private PreferencesDialog preferencesDialog;
-		//VideoConversation videoConversation;
-		private Conversation conversation = null;
-		private bool initiatedConversation = false;
 		
 		private Dictionary<GroupWindow, GroupWindow> groupWindows;
-
-		// Major temporary hack
-		//private Novell.Rtc.Connection conn = null;
-		
-		// Extend the hack to tapioca
-		//Tapioca.UserContact meContact = null;
-		Tapioca.Connection tapConnection = null;
-		ManualResetEvent connectedEvent = null;
-		
 		#endregion
 	
 		#region Public Static Properties
@@ -113,7 +100,7 @@ namespace Banter
 		#region Private Methods
 		private void Init(string[] args)
 		{
-			Console.WriteLine ("Banter.Application constructor");
+			Logger.Debug ("Banter::Application::Init - called");
 			initialized = false;
 			Gtk.Application.Init ();
 			program = 
@@ -126,6 +113,10 @@ namespace Banter
 			// Call Init before anything so the people objects are in place
 			PersonStore.Instance.Init();
 			
+			// Create and start up the Person Sync
+			personSync = new PersonSync();
+			personSync.Start();
+			
 			actionManager = new ActionManager ();
 			actionManager.LoadInterface ();
 			SetUpGlobalActions ();
@@ -143,7 +134,7 @@ namespace Banter
 	
 		private void SetupTrayIcon ()
 		{
-			Console.WriteLine ("Creating TrayIcon");
+			Logger.Debug ("Creating TrayIcon");
 			
 			EventBox eb = new EventBox();
 			appPixBuf = GetIcon ("banter-22", 22);
@@ -160,7 +151,7 @@ namespace Banter
 		
 		private bool InitializeIdle ()
 		{
-			Console.WriteLine ("Initialize_Idle - called");
+			Logger.Debug ("Initialize_Idle - called");
 
 			//GConfPreferencesProvider prefs = new GConfPreferencesProvider ();
 			//Preferences.Init (prefs);
@@ -178,7 +169,7 @@ namespace Banter
 			
 			// Start account management and authenticate to any auto-login accounts
 			AccountManagement.IAmUpEvent += OnAccountManagementReadyEvent;
-			AccountManagement.Start ();
+			AccountManagement.Initialize ();
 			
 			/*
 			if ((bool) Preferences.Get (Preferences.ENABLE_TRAY_ICON))
@@ -200,7 +191,7 @@ namespace Banter
 		
 		private void OnAccountManagementReadyEvent ()
 		{
-			Logger.Debug("OnAccountManagementReady() called");
+			Logger.Debug ("OnAccountManagementReady() called");
 			InitializePersons();
 			initialized = true;
 			
@@ -210,208 +201,39 @@ namespace Banter
 		private bool OpenSavedGroupWindows ()
 		{
 			GroupWindow gw;
-			string[] groupWindowIds = Preferences.Get (Preferences.GroupWindows) as String[];
-			if (groupWindowIds == null) {
-				// Create a new Group Window with Everyone selected
-				gw = new GroupWindow ();
-				groupWindows [gw] = gw;
-				gw.DeleteEvent += OnGroupWindowDeleted;
-				gw.ShowAll ();
-				return false;
-			}
 			
-			foreach (string id in groupWindowIds) {
-				gw = new GroupWindow (id);
-				
-				groupWindows [gw] = gw;
-				gw.DeleteEvent += OnGroupWindowDeleted;
-				gw.ShowAll ();
+			try {
+				string[] groupWindowIds = Preferences.Get (Preferences.GroupWindows) as String[];
+				if (groupWindowIds == null) {
+					// Create a new Group Window with Everyone selected
+					gw = new GroupWindow ();
+					groupWindows [gw] = gw;
+					gw.DeleteEvent += OnGroupWindowDeleted;
+					gw.ShowAll ();
+				} else {
+					foreach (string id in groupWindowIds) {
+						gw = new GroupWindow (id);
+						
+						groupWindows [gw] = gw;
+						gw.DeleteEvent += OnGroupWindowDeleted;
+						gw.ShowAll ();
+					}
+				}
+			} catch (Exception osgw) {
+				Logger.Debug (osgw.Message);
+				Logger.Debug (osgw.StackTrace);
 			}
 			
 			return false; // Prevent GLib.Idle from calling this method again
 		}
 
-		private void OnNewChannel (Tapioca.Connection sender, Tapioca.Channel channel)
-		{
-			Logger.Debug ("Application::OnNewChannel - called");
-			
-			if (initiatedConversation == true)
-				return;
-				
-			/*
-			Logger.Debug ("Checking for contacts");
-			Logger.Debug (
-				"# contacts in channel: {0}",
-				channel.ContactGroup.Contacts.Length);
-			foreach (Contact ct in channel.ContactGroup.Contacts)
-				Logger.Debug (ct.Uri);
-			Logger.Debug (
-				"# pending contacts in channel: {0}", 
-				channel.ContactGroup.PendingContacts.Length);
-			*/	
-		
-			try
-			{
-				Conversation conversation = null;
-				
-				switch (channel.Type)
-				{
-					case Tapioca.ChannelType.Text:
-					{
-						TextChannel txtChannel = channel as TextChannel;
-						conversation = 
-							new Conversation (sender, txtChannel.RemoteTarget as Contact);
-						conversation.SetTextChannel (txtChannel);
-
-						Person peer = GetPersonFromContact (txtChannel.RemoteTarget as Contact);
-						ChatWindow cw = null;
-						
-						if (chatWindows.ContainsKey (peer.Id)) {
-							chatWindows[peer.Id].Present();
-						}
-						else {
-							try
-							{
-								cw = new ChatWindow ();
-								cw.Conversation = conversation;
-								cw.DeleteEvent += OnChatWindowDelete;
-								chatWindows[peer.Id] = cw;
-								cw.Present();
-							}
-							catch (Exception es)
-							{
-								Console.WriteLine (es.Message);
-								Console.WriteLine (es.StackTrace);
-							}
-						}
-						break;
-					}
-					
-					case Tapioca.ChannelType.StreamedMedia:
-					{
-						VideoWindow meWindow = new VideoWindow();
-						meWindow.Title = "Me";
-						meWindow.Show();
-				
-						VideoWindow youWindow = new VideoWindow();
-						youWindow.Title = "You";
-						youWindow.Show();
-						
-						StreamChannel strmChannel =	channel as StreamChannel;
-
-						conversation = 
-							new Conversation (sender, strmChannel.RemoteTarget as Contact);
-					
-						conversation.SetVideoWindows (meWindow.WindowId, youWindow.WindowId);
-						conversation.SetStreamedMediaChannel (strmChannel);
-						break;
-					}
-				}
-			
-			}
-			catch (Exception onc)
-			{
-				Logger.Debug (onc.Message);
-				Logger.Debug (onc.StackTrace);
-			}
-			
-		}
-
-		private void OnConnectionChanged ( 
-			Tapioca.Connection sender,
-			Tapioca.ConnectionStatus status,
-			Tapioca.ConnectionStatusReason reason)
-		{
-			Logger.Debug ("OnConnectionChanged - called");
-			Logger.Debug ("  {0}", status.ToString());
-			
-			switch (status)
-			{
-				case Tapioca.ConnectionStatus.Connecting:
-				{
-					break;
-				}
-				
-				case Tapioca.ConnectionStatus.Connected:
-				{
-					Logger.Debug ("  in connected");
-					
-					try
-					{
-						Logger.Debug ("ME - uri: {0}", tapConnection.Info.Uri);
-						Logger.Debug ("ME - alias: {0}", tapConnection.Info.Alias);
-						Logger.Debug ("ME - caps: {0}", tapConnection.Info.Capabilities.ToString());
-						Logger.Debug ("ME - avatar token: {0}", tapConnection.Info.CurrentAvatarToken);
-						
-						/*
-						Person person = new Person(tapConnection.Info, true);
-						persons[tapConnection.Info.Handle.Id] = person;
-						this.me = person;
-						*/
-						
-						Logger.Debug ("# Subscribed Contacts: {0}", tapConnection.ContactList.SubscribedContacts.Length);
-						Logger.Debug ("# Known Contacts: {0}", tapConnection.ContactList.KnownContacts.Length);
-
-						Logger.Debug ("Connection jabber requested");
-						
-						// Loop through and add all of the subscribed contacts
-		 				foreach (Contact c in tapConnection.ContactList.KnownContacts) //.SubscribedContacts)
-						{
-		                 	Logger.Debug (
-		                 		"Contact Retrieved\n\t{0}/{4} - {1}/{2} - {3}",
-		                 		c.Uri, 
-		                 		c.Presence, 
-		                 		c.PresenceMessage, 
-		                 		c.SubscriptionStatus, 
-		                 		c.Alias);
-
-							if(!persons.ContainsKey (c.Handle.Id)) {
-								Person person = PersonStore.GetPersonByJabberId(c.Handle.Name);
-								if(person == null) {
-									person = new Person(c.Alias);
-									person.JabberId = c.Handle.Name;
-									PersonStore.AddPerson(person);
-								}
-								
-								person.Contact = c;
-								persons[c.Handle.Id] = person;
-							}
-		                }
-		                
-						// FIXME - For now we have all caps		                
-						tapConnection.Info.SetCapabilities (
-							ContactCapabilities.Text |
-							ContactCapabilities.Audio |
-							ContactCapabilities.Video);
-		                
-		                // Setup handlers for incoming conversations
-		                sender.ChannelCreated += OnNewChannel;
-					}
-					catch (Exception on)
-					{	
-						Logger.Debug (on.Message);
-						Logger.Debug (on.StackTrace);
-					}
-					
-					if (this.connectedEvent != null)
-						this.connectedEvent.Set();
-						
-					break;
-				}
-				
-				case Tapioca.ConnectionStatus.Disconnected:
-				{
-					break;
-				}
-			}
-		}
-		
 		private void InitializePersons()
 		{
 			Logger.Debug("InitializePersons called");
 
 			persons = new Dictionary<uint,Person> ();
 
+			/*
 			try
 			{
 				Banter.Account rtcAccount = null;
@@ -420,97 +242,19 @@ namespace Banter
 					rtcAccount = account;
 					break;
 				}
+				
+				if (rtcAccount == null)
+					throw new ApplicationException ("No Available accounts to connect to");
 	
-				System.Collections.Generic.Dictionary <string, object> options =
-					rtcAccount.Options;
-			
-				ConnectionManagerFactory cmFactory = new ConnectionManagerFactory ();
-	              
-	            Logger.Debug ("user account: {0}", options["account"]);
-	              
-				System.Collections.ArrayList ps = new System.Collections.ArrayList ();
-				ps.Add (new ConnectionManagerParameter ("account", options["account"]));
-				ps.Add (new ConnectionManagerParameter ("password", options["password"]));
-				ps.Add (new ConnectionManagerParameter ("server", options["server"]));
-				//ps.Add (new ConnectionManagerParameter ("server", "talk.google.com"));
-				ps.Add (new ConnectionManagerParameter ("old-ssl", true));
-				ps.Add (new ConnectionManagerParameter ("ignore-ssl-errors", true));
-				ps.Add (new ConnectionManagerParameter ("port", (uint) 5223));
-
-				ConnectionManagerParameter[] parameters = 
-					(ConnectionManagerParameter[]) ps.ToArray (typeof (ConnectionManagerParameter));
-
-				Logger.Debug ("Creating connection");
-				ConnectionManager cm = cmFactory.GetConnectionManager ("jabber");
-				if (cm == null) {
-				       Logger.Debug ("Error geting CM");
-				       return;
-				}
-				Console.WriteLine ("Connection created");
+				rtcAccount.Connect (false);
 				
-				/*
-				Logger.Debug ("#parameters: {0}", parameters.Length);
-				foreach (ConnectionManagerParameter pm in parameters)
-					Logger.Debug ("name: {0} - value: {1}", pm.Name, pm.Value);
-				*/
-
-				tapConnection = cm.RequestConnection ("jabber", parameters);
-				if (tapConnection == null) {
-				       Logger.Debug ("Error on RequestConnection");
-				       return;
-				}
-			
-				connectedEvent = new ManualResetEvent (false);
-				tapConnection.StatusChanged += OnConnectionChanged;
-				tapConnection.Connect (Tapioca.ContactPresence.Available);
-				
-				connectedEvent.WaitOne (20000, true);
-				Thread.Sleep(2000);
-
-				if (tapConnection.Status != Tapioca.ConnectionStatus.Connected)
+				if (rtcAccount.Connected == false)
 				{
 					throw new ApplicationException (
 								String.Format ("Failed to connect \"{0}\"", 
 									rtcAccount.Username));
 									//rtcAccount.TelepathyBusName));
 				}
-				
-				Logger.Debug ("Connection Status: {0}", tapConnection.Status.ToString());
-				
-
-			
-				/*
-				foreach(Account account in AccountManagement.GetAccounts())
-				{
-					conn = new Novell.Rtc.Connection (account);
-					conn.Connect ();
-					Member me = conn.GetSelf();
-					Console.WriteLine ("Me - Name: {0}  Alias: {1}", me.ScreenName, me.Alias);
-					Person person = new Person(me);
-					person.IsSelf = true;
-					persons[me.Handle] = person;
-					this.me = person;
-					
-							
-					Member[] members = conn.GetActiveMembers();
-							
-					foreach (Member member in members)
-					{
-						if(!persons.ContainsKey(member.Handle))
-							persons[member.Handle] = new Person(member);
-						
-						Console.WriteLine (
-							"Member - Handle: {0} Name: {1}  Alias: {2} Presence: {3}", 
-							member.Handle, 
-							member.ScreenName, 
-							member.Alias,
-							member.Presence.ToString());
-					}
-					
-					conn.IncomingConversation += OnIncomingConversation;
-					conn.IncomingMediaConversation += OnIncomingMediaConversation;
-				}
-				*/
 			}
 			catch (Exception es)
 			{
@@ -519,15 +263,10 @@ namespace Banter
 			}
 			finally
 			{
-					/*
-					if (friends != null)
-						foreach (Person friend in friends)
-							friend.Dispose();
-					*/
 			}
+			*/
 		}
 
-		
 		private void OnImageClick (object o, ButtonPressEventArgs args) // handler for mouse click
 		{
 			if(!initialized)
@@ -618,6 +357,9 @@ namespace Banter
 		private void OnQuit (object o, System.EventArgs args)
 		{
 			actionManager ["QuitAction"].Activate ();
+
+			// stop the personSync
+			personSync.Stop();
 		}
 		
 		private void OnQuitAction (object sender, EventArgs args)
@@ -632,25 +374,11 @@ namespace Banter
 				}
 			}
 			
-			/*
-			// Temporary disconnect from our single account			
-			if (conn != null && conn.Connected == true) {
-				conn.Disconnect ();
-				conn = null;
-			}
-			*/
+			AccountManagement.Shutdown();
+			Logger.Debug ("Finished Disconnecting accounts");
 
-			if (tapConnection != null)			
-				tapConnection.Disconnect ();
-
-			// Unauthenticate all accounts
-			AccountManagement.Stop ();
-			
 			// Shutdown the messaging engine
 			//MessageEngine.Stop ();
-
-			// Shutdown all the telepathy providers that were loaded
-			//TelepathyProviderFactory.Stop ();
 			
 			// Shutdown the message log store
 			//MessageStore.Stop ();
@@ -694,8 +422,9 @@ namespace Banter
 			}
 
 			// FIXME: Remove this eventually.  It's a hack to retry starting the AccountManager assuming the user entered credentials
-			if (!initialized) {
-				AccountManagement.Start ();
+			if (!initialized && AccountManagement.InitializedFinished() == false)
+			{
+				AccountManagement.Initialize ();
 			}
 		}
 		
@@ -838,26 +567,27 @@ Logger.Debug ("Application.OnGroupWindowDeleted");
 			throw new ApplicationException("Fixme: The dude is not found, create real exceptions");
 		}
 		
-		public void InitiateTapiocaChat(Person person)
+		public void InitiateChat(Person person)
 		{
-			Console.WriteLine("Called to initiate chat with: " + person.DisplayName);
-			initiatedConversation = true;
+			Logger.Debug ("Called to initiate chat with: " + person.DisplayName);
 			
-			if(chatWindows.ContainsKey(person.Id))
-				chatWindows[person.Id].Present();
+			if (ChatWindow.AlreadyExist (person.Id) == true)
+				ChatWindow.PresentWindow (person.Id);
 			else
 			{
 				try
 				{
-					ChatWindow cw = new ChatWindow();
-					cw.DeleteEvent += OnChatWindowDelete;
-					chatWindows[person.Id] = cw;
-
+					// FIXEME::temporary hack
+				
+					Banter.Account acct = null;
+					foreach (Banter.Account account in AccountManagement.GetAccounts())
+					{
+						acct = account;
+						break;
+					}
+				
 					Conversation conversation = 
-						new Conversation(tapConnection, person.Contact);
-					conversation.CreateTextChannel();
-					cw.Conversation = conversation;
-					cw.Present();
+						Banter.ConversationManager.Create (acct, person, true);
 				}
 				catch (Exception es)
 				{
@@ -867,10 +597,9 @@ Logger.Debug ("Application.OnGroupWindowDeleted");
 			}
 		}
 
-		public void InitiateTapiocaVideoChat(Person person)
+		public void InitiateVideoChat(Person person)
 		{
-			Console.WriteLine("Called to initiate Video chat with: " + person.DisplayName);
-			initiatedConversation = true;
+			Logger.Debug ("Called to initiate Video chat with: " + person.DisplayName);
 			
 			VideoWindow meWindow = new VideoWindow();
 			meWindow.Title = "Me";
@@ -880,24 +609,27 @@ Logger.Debug ("Application.OnGroupWindowDeleted");
 			youWindow.Title = "You";
 			youWindow.Show();
 			
+			/*
 			if (this.conversation == null)
 			{
-				this.conversation = new Conversation (tapConnection, person.Contact);
+				this.conversation = new Conversation (tapConnection, person);
 				this.conversation.SetVideoWindows (meWindow.WindowId, youWindow.WindowId);
 				this.conversation.StartVideoChat ();
 			}
+			*/
 		}		
 
-		public void InitiateTapiocaAudioChat (Person person)
+		public void InitiateAudioChat (Person person)
 		{
-			Console.WriteLine("Called to initiate Audio chat with: " + person.DisplayName);
-			initiatedConversation = true;
-			
+			Logger.Debug ("Called to initiate Audio chat with: " + person.DisplayName);
+
+			/*			
 			if (this.conversation == null)
 			{
-				this.conversation = new Conversation (tapConnection, person.Contact);
+				this.conversation = new Conversation (tapConnection, person);
 				this.conversation.StartAudioChat ();
 			}
+			*/
 		}		
 		
 		private void OnChatWindowDelete (object sender, DeleteEventArgs args)
@@ -905,7 +637,7 @@ Logger.Debug ("Application.OnGroupWindowDeleted");
 			ChatWindow cw = sender as ChatWindow;
 			if (chatWindows.ContainsValue (cw))
 			{
-				Person person = persons[cw.Conversation.PeerContact.Handle.Id];
+				Person person = persons[cw.Conversation.PeerUser.Contact.Handle.Id];
 				if(person != null)
 					chatWindows.Remove (person.Id);
 			}
